/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.urlhandlers;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.wso2.registry.jdbc.ConnectionFactory;
import org.wso2.registry.jdbc.dao.TagsDAO;
import org.wso2.registry.jdbc.dao.RatingsDAO;
import org.wso2.registry.Resource;
import org.wso2.registry.RegistryException;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;
import java.util.ArrayList;

public class RatingsCollectionURLHandler extends URLHandler {

    private static final Log log = LogFactory.getLog(CommentCollectionURLHandler.class);

    public RatingsCollectionURLHandler(ConnectionFactory connectionFactory) {
        super(connectionFactory);
    }

    public boolean handleURL(String url, Resource resource) throws RegistryException {

        String[] parts = url.split(";");

        if (parts.length != 2) {
            return false;
        }

        if (parts[0].length() == 0) {
            return false;
        }

        if (!parts[1].equals("ratings")) {
            return false;
        }

        if (parts[1].length() != "ratings".length()) {
            return false;
        }

        String resourcePath = parts[0];

        Connection conn = connectionFactory.getConnection();
        RatingsDAO ratingsDAO = new RatingsDAO();

        try {
            resource.setPath(url);
            resource.setDirectory(true);

            String[] ratedUserNames = ratingsDAO.getRatedUserNames(resourcePath, conn);
            List ratingPaths = new ArrayList();
            for (int i = 0; i < ratedUserNames.length; i++) {
                String ratingPath = resourcePath + ";ratings:" + ratedUserNames[i];
                ratingPaths.add(ratingPath);
            }

            String[] ratingsContent =
                    (String[]) ratingPaths.toArray(new String[ratingPaths.size()]);
            resource.setContent(ratingsContent);

            return true;

        } catch (SQLException e) {
            String msg = "Failed to get ratings for resource: " +
                    resourcePath + ". Caused by: " + e.getMessage();
            log.error(msg, e);
            throw new RegistryException(msg);

        } finally {
            try {
                conn.close();
            } catch (SQLException ignore) {

            }
        }
    }
}
